package App::LDAP::Command::Migrate::User;

use Modern::Perl;

use Namespace::Dispatch;

use Moose;

with 'MooseX::Getopt';

sub run {

}

__PACKAGE__->meta->make_immutable;
no Moose;

1;
